@@ -1,8 +1,8 @@
 """
 OpenSCM Units, units for use with simple climate modelling
 """
+from ._unit_registry import ScmUnitRegistry, unit_registry  # noqa: F401
 from ._version import get_versions
-from .unit_registry import unit_registry  # noqa: F401
 
 __version__ = get_versions()["version"]
 del get_versions
