@@ -4,7 +4,7 @@ allows us to easily define units as well as contexts. Contexts allow us to perfo
 conversions which would not normally be allowed e.g. in the 'AR4GWP100'
 context we can convert from CO2 to CH4 using the AR4GWP100 equivalence metric.
 
-An illustration of how the ``unit_regsitry`` can be used is shown below:
+An illustration of how the ``unit_registry`` can be used is shown below:
 
 .. code:: python
 
@@ -34,9 +34,8 @@ For emissions units, there are a few cases to be considered:
 
 - fairly obvious ones e.g. carbon dioxide emissions can be provided in 'C' or 'CO2' and
   converting between the two is possible
-- less obvious ones e.g. nitrous oxide emissions can be provided in 'N', 'N2O' or
-  'N2ON' (a short-hand which indicates that only the mass of the nitrogen is being counted),
-  we provide conversions between these three
+- less obvious ones e.g. NOx emissions can be provided in 'N' or 'NOx' (a short-hand
+  which is assumed to be NO2), we provide conversions between these two
 - case-sensitivity. In order to provide a simplified interface, using all uppercase
   versions of any unit is also valid e.g. ``unit_registry("HFC4310mee")`` is the same as
   ``unit_registry("HFC4310MEE")``
@@ -85,6 +84,29 @@ However, it can be performed within the context 'CH4_conversions' as shown below
     ...     unit_registry("CH4").to("CO2")
     <Quantity(2.75, 'CO2')>
 
+*N2O*
+
+Nitrous oxide emissions are typically reported with units of 'N2O'. However,
+they are also reported with units of 'N2ON' (a short-hand which indicates that
+only the mass of the nitrogen is being counted). Reporting nitrous oxide
+emissions with units of simply 'N' is ambiguous (do you mean the mass of
+nitrogen, so 1 N = 28 / 44 N2O or just the mass of a single N atom, so
+1 N = 14 / 44 N2O). By default, converting 'N2O' <--> 'N' is forbidden to
+prevent this ambiguity. However, the conversion can be performed within the
+context 'N2O_conversions', in which case it is assumed that 'N' just means a
+single N atom i.e. 1 N = 14 / 44 N2O, as shown below:
+
+.. code:: python
+
+    >>> from openscm_units import unit_registry
+    >>> unit_registry("N2O").to("N")
+    pint.errors.DimensionalityError: Cannot convert from 'N2O' ([nitrous_oxide]) to 'N' ([nitrogen])
+
+    # with a context, the conversion becomes legal again
+    >>> with unit_registry.context("N2O_conversions"):
+    ...     unit_registry("N2O").to("N")
+    <Quantity(0.318181818, 'N')>
+
 *NOx*
 
 Like for methane, NOx emissions also suffer from a namespace collision. In order to
@@ -102,16 +124,33 @@ prevent inadvertent conversions from 'NOx' to e.g. 'N2O', the conversion 'NOx' <
     ...     unit_registry("NOx").to("N")
     <Quantity(0.30434782608695654, 'N')>
 
-    # as an unavoidable side effect, this also becomes possible
-    >>> with unit_registry.context("NOx_conversions"):
-    ...     unit_registry("NOx").to("N2O")
-    <Quantity(0.9565217391304348, 'N2O')>
+*NH3*
+
+In order to prevent inadvertent conversions from 'NH3' to 'CO2', the conversion
+'NH3' <--> 'N' is by default forbidden. It can be performed within the 'NH3_conversions'
+context analogous to the 'NOx_conversions' context:
+
+.. code:: python
+
+    >>> from openscm_units import unit_registry
+    >>> unit_registry("NH3").to("N")
+    pint.errors.DimensionalityError: Cannot convert from 'NH3' ([NH3]) to 'N' ([nitrogen])
+
+    # with a context, the conversion becomes legal again
+    >>> with unit_registry.context("NH3_conversions"):
+    ...     unit_registry("NH3").to("N")
+    <Quantity(0.823529412, 'N')>
+
 """
-from os import path
+import importlib
+import math
 
 import pandas as pd
 import pint
 
+from . import data  # pylint:disable=no-name-in-module # no idea why this is failing
+from .data.mixtures import MIXTURES
+
 # Standard gases. If the value is:
 # - str: this entry defines a base gas unit
 # - list: this entry defines a derived unit
@@ -122,14 +161,16 @@ _STANDARD_GASES = {
     "C": "carbon",
     "CO2": ["12/44 * C", "carbon_dioxide"],
     "CH4": "methane",
+    "HC50": ["CH4"],
+    "N2O": "nitrous_oxide",
+    "N2ON": ["44/28 * N2O", "nitrous_oxide_farming_style"],
     "N": "nitrogen",
-    "N2O": ["14/44 * N", "nitrous_oxide"],
-    "N2ON": ["14/28 * N", "nitrous_oxide_farming_style"],
     "NO2": ["14/46 * N", "nitrogen_dioxide"],
     # aerosol precursors
     "NOx": "NOx",
     "nox": ["NOx"],
-    "NH3": ["14/17 * N", "ammonia"],
+    "NH3": "NH3",
+    "ammonia": ["NH3"],
     "S": "sulfur",
     "SO2": ["32/64 * S", "sulfur_dioxide"],
     "SOx": ["SO2"],
@@ -145,9 +186,26 @@ _STANDARD_GASES = {
     "CFC113": "CFC113",
     "CFC114": "CFC114",
     "CFC115": "CFC115",
+    # hydrocarbons
+    "C2H6": "ethane",
+    "HC170": ["C2H6"],
+    "C3H8": "propane",
+    "HC290": ["C3H8"],
+    "HC600": "HC600",
+    "butane": ["HC600"],
+    "HC600a": "HC600a",
+    "isobutane": ["HC600a"],
+    "HC601": "HC601",
+    "pentane": ["HC601"],
+    "HC601a": "HC601a",
+    "isopentane": ["HC601a"],
+    "HCE170": "HCE170",
+    "HO1270": "HO1270",
+    "propene": ["HO1270"],
     # HCFCs
     "HCFC21": "HCFC21",
     "HCFC22": "HCFC22",
+    "HCFC31": "HCFC31",
     "HCFC123": "HCFC123",
     "HCFC124": "HCFC124",
     "HCFC141b": "HCFC141b",
@@ -175,6 +233,7 @@ _STANDARD_GASES = {
     "HFC365mfc": "HFC365mfc",
     "HFC4310mee": "HFC4310mee",
     "HFC4310": ["HFC4310mee"],
+    "HFC1336mzz": "HFC1336mzz",
     # Halogenated gases
     "Halon1201": "Halon1201",
     "Halon1202": "Halon1202",
@@ -184,9 +243,12 @@ _STANDARD_GASES = {
     # PFCs
     "CF4": "CF4",
     "C2F6": "C2F6",
+    "PFC116": ["C2F6"],
     "cC3F6": "cC3F6",
     "C3F8": "C3F8",
+    "PFC218": ["C3F8"],
     "cC4F8": "cC4F8",
+    "PFCC318": ["cC4F8"],
     "C4F10": "C4F10",
     "C5F12": "C5F12",
     "C6F14": "C6F14",
@@ -223,6 +285,9 @@ _STANDARD_GASES = {
     "HFE374pc2": "HFE374pc2",
     # Perfluoropolyethers
     "PFPMIE": "PFPMIE",
+    # Hydrofluoroolefins
+    "HFO1234yf": "HFO1234yf",
+    "HFO1234ze": "HFO1234ze",
     # Misc
     "CCl4": "CCl4",
     "CHCl3": "CHCl3",
@@ -234,6 +299,7 @@ _STANDARD_GASES = {
     "SF6": "SF6",
     "SO2F2": "SO2F2",
     "NF3": "NF3",
+    "HCO1130": "HCO1130",
 }
 
 
@@ -247,6 +313,25 @@ class ScmUnitRegistry(pint.UnitRegistry):
 
     _contexts_loaded = False
 
+    def __init__(self, *args, metric_conversions_csv=None, **kwargs):
+        """
+        Initialise the unit registry
+
+        Parameters
+        ----------
+        metric_conversions_csv : str
+            csv file containing the metric conversions. If not supplied,
+            the internal metric conversions csv is used.
+
+        *args
+            Passed to the ``__init__`` method of the super class
+
+        **kwargs
+            Passed to the ``__init__`` method of the super class
+        """
+        self._metric_conversions_csv = metric_conversions_csv
+        super().__init__(*args, **kwargs)
+
     def add_standards(self):
         """
         Add standard units.
@@ -255,6 +340,8 @@ class ScmUnitRegistry(pint.UnitRegistry):
         """
         self._add_gases(_STANDARD_GASES)
 
+        self._add_gases({x: x for x in MIXTURES.keys()})
+
         self.define("a = 1 * year = annum = yr")
         self.define("h = hour")
         self.define("d = day")
@@ -329,16 +416,38 @@ class ScmUnitRegistry(pint.UnitRegistry):
         )
         self.add_context(_ch4_context)
 
-        _n2o_context = pint.Context("NOx_conversions")
+        _n2o_context = pint.Context("N2O_conversions")
         _n2o_context = self._add_transformations_to_context(
             _n2o_context,
+            "[nitrous_oxide]",
+            self.nitrous_oxide,
+            "[nitrogen]",
+            self.nitrogen,
+            14 / 44,
+        )
+        self.add_context(_n2o_context)
+
+        _nox_context = pint.Context("NOx_conversions")
+        _nox_context = self._add_transformations_to_context(
+            _nox_context,
             "[nitrogen]",
             self.nitrogen,
             "[NOx]",
             self.NOx,
             (14 + 2 * 16) / 14,
         )
-        self.add_context(_n2o_context)
+        self.add_context(_nox_context)
+
+        _nh3_context = pint.Context("NH3_conversions")
+        _nh3_context = self._add_transformations_to_context(
+            _nh3_context,
+            "[nitrogen]",
+            self.nitrogen,
+            "[NH3]",
+            self.NH3,
+            (14 + 3) / 14,
+        )
+        self.add_context(_nh3_context)
 
         self._load_metric_conversions()
 
@@ -348,12 +457,13 @@ class ScmUnitRegistry(pint.UnitRegistry):
 
         This is done only when contexts are needed to avoid reading files on import.
         """
+        if self._metric_conversions_csv is None:
+            to_read = importlib.resources.open_text(data, "metric_conversions.csv")
+        else:
+            to_read = self._metric_conversions_csv
+
         metric_conversions = pd.read_csv(
-            path.join(
-                path.dirname(path.abspath(__file__)),
-                "data",
-                "metric_conversions.csv",
-            ),
+            to_read,
             skiprows=1,  # skip source row
             header=0,
             index_col=0,
@@ -361,40 +471,65 @@ class ScmUnitRegistry(pint.UnitRegistry):
             1:, :
         ]  # drop out 'SCMData base unit' row
 
-        other_unit_ureg = self.carbon
+        self._add_metric_conversions_from_df(metric_conversions)
 
+    def _add_metric_conversions_from_df(self, metric_conversions):
+        # could make this public in future so people can write conversions
+        # in memory and then set them
         for col in metric_conversions:
+            metric_conversion = metric_conversions[col]
             transform_context = pint.Context(col)
-            for label, val in metric_conversions[col].iteritems():
-                conv_val = (
-                    val
-                    * (self("CO2").to_base_units()).magnitude
-                    / (self(label).to_base_units()).magnitude
-                )
-                base_unit = [
-                    s
-                    for s, _ in self._get_dimensionality(
-                        self(label)  # pylint: disable=protected-access
-                        .to_base_units()
-                        ._units
-                    ).items()
-                ][0]
-
-                base_unit_ureg = getattr(
-                    self, base_unit.replace("[", "").replace("]", "")
+            for label, val in metric_conversion.iteritems():
+                transform_context = self._add_gwp_to_context(
+                    transform_context, label, val
                 )
 
-                transform_context = self._add_transformations_to_context(
-                    transform_context,
-                    base_unit,
-                    base_unit_ureg,
-                    "[carbon]",
-                    other_unit_ureg,
-                    conv_val,
+            for mixture in MIXTURES:
+                constituents = self.split_gas_mixture(1 * self(mixture))
+                try:
+                    val = sum(
+                        c.magnitude * metric_conversion[str(c.units)]
+                        for c in constituents
+                    )
+                except KeyError:  # gwp not available for all constituents
+                    continue
+                if math.isnan(val):
+                    continue
+                transform_context = self._add_gwp_to_context(
+                    transform_context, mixture, val
                 )
 
             self.add_context(transform_context)
 
+    def _add_gwp_to_context(
+        self, transform_context: pint.Context, label: str, val: float
+    ) -> pint.Context:
+        conv_val = (
+            val
+            * (self("CO2").to_base_units()).magnitude
+            / (self(label).to_base_units()).magnitude
+        )
+        base_unit = next(
+            iter(
+                self._get_dimensionality(
+                    self(label)  # pylint: disable=protected-access
+                    .to_base_units()
+                    ._units
+                ).keys()
+            )
+        )
+
+        base_unit_ureg = self(base_unit.replace("[", "").replace("]", ""))
+
+        return self._add_transformations_to_context(
+            transform_context,
+            base_unit,
+            base_unit_ureg,
+            "[carbon]",
+            self("carbon"),
+            conv_val,
+        )
+
     @staticmethod
     def _add_transformations_to_context(
         context, base_unit, base_unit_ureg, other_unit, other_unit_ureg, conv_val
@@ -439,6 +574,39 @@ class ScmUnitRegistry(pint.UnitRegistry):
 
         return context
 
+    def split_gas_mixture(self, quantity: pint.Quantity) -> list:
+        """
+        Split a gas mixture into constituent gases.
+
+        Given a pint quantity with the units containing a gas mixture,
+        returns a list of the constituents as pint quantities.
+        """
+        mixture_dimensions = [
+            x for x in quantity.dimensionality.keys() if x[1:-1] in MIXTURES
+        ]
+        if not mixture_dimensions:
+            raise ValueError("Dimensions don't contain a gas mixture.")
+        if len(mixture_dimensions) > 1:
+            raise NotImplementedError(
+                "More than one gas mixture in dimensions is not supported."
+            )
+        mixture_dimension = mixture_dimensions[0]
+        if quantity.dimensionality[mixture_dimension] != 1:
+            raise NotImplementedError(
+                f"Mixture has dimensionality {quantity.dimensionality[mixture_dimension]}"
+                " != 1, which is not supported."
+            )
+
+        mixture = MIXTURES[mixture_dimension[1:-1]]
+        mixture_unit = self(mixture_dimension[1:-1])
+
+        ret = []
+        for constituent, (fraction_pct, _, _) in mixture.items():
+            constituent_unit = self(constituent)
+            ret.append(quantity / mixture_unit * fraction_pct / 100 * constituent_unit)
+
+        return ret
+
 
 unit_registry = ScmUnitRegistry()  # pylint:disable=invalid-name
 """
